Conversational Space Map App
****************************


Generate conversational space maps for interview data, inspired by Saunders et al. (2023, pp. 458-460).

.. image:: https://raw.githubusercontent.com/manuelbieri/ConversationalSpaceMapApp/master/src/conversationalspacemapapp/resources/Screenshot.png
   :width: 600
   :alt: App screenshot
   :align: center

Quickstart
============================

Note: This quickstart guide assumes that you have already installed Python and Git.

1. Download or clone the repository

.. code-block:: bash

    $ git clone https://github.com/manuelbieri/ConversationalSpaceMap.git

2. Create a virtual environment.

3. Install dependencies (in your virtual environment).

.. code-block:: bash

    $ pip install .

4. Run the app (`see this tutorial <https://docs.beeware.org/en/latest/tutorial/tutorial-3.html#building-your-application>`_).

.. code-block:: bash

    $ briefcase run

(5. Package the app for local installation)

.. code-block:: bash

    $ briefcase package

How to use
============================

.. image:: https://raw.githubusercontent.com/manuelbieri/ConversationalSpaceMapApp/master/src/conversationalspacemapapp/resources/Menubar.png
   :width: 600
   :align: center
   :alt: Menubar screenshot

References
============================
**Saunders, Mark, Philip Lewis, and Adrian Thornhill**, *Research methods for business students*, 9 ed., Harlow, England: Pearson, 2023.
